@@ -227,6 +227,17 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 	}
 
 
+	/* (non-Javadoc)
+	 * @see org.gcube.common.storagehubwrapper.server.tohl.Workspace#markAsPublic(java.lang.String, boolean)
+	 */
+	@Override
+	public Boolean markAsPublic(String itemId, boolean isPublic) {
+
+		//TODO
+		return false;
+	}
+
+
 
 	/* (non-Javadoc)
 	 * @see org.gcube.portal.storagehubwrapper.shared.Workspace#getOwner()
@@ -253,7 +264,7 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 			logger.error("Error on getting root: ", e);
 			throw new InternalErrorException("Sorry an error occurred when getting the workspace root. Refresh and try again");
 		}
-		WorkspaceFolder workspaceFolder = (WorkspaceFolder) HLMapper.toWorkspaceItem(root);
+		WorkspaceFolder workspaceFolder = (WorkspaceFolder) HLMapper.toWorkspaceItem(root, withAccounting, withFileDetails, withMapProperties);
 		workspaceFolder.setRoot(true);
 		return workspaceFolder;
 	}
@@ -265,11 +276,11 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 	public List<? extends WorkspaceItem> getChildren(String id) throws Exception{
 
 		Validate.notNull(id,"The input id is null");
-		List<? extends Item> children = storageHubClientService.getChildren(id);
+		List<? extends Item> children = storageHubClientService.getChildren(id, withAccounting, withMapProperties);
 		List<WorkspaceItem> toChildren = new ArrayList<WorkspaceItem>(children.size());
 
 		for (Item item : children) {
-			WorkspaceItem child = HLMapper.toWorkspaceItem(item);
+			WorkspaceItem child = HLMapper.toWorkspaceItem(item, withAccounting, withFileDetails, withMapProperties);
 			toChildren.add(child);
 		}
 
@@ -282,11 +293,11 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 	public List<? extends WorkspaceItem> getFilteredChildren(String id, Class<? extends Item> aType) throws Exception{
 
 		Validate.notNull(id,"The input id is null");
-		List<? extends Item> children = storageHubClientService.getFilteredChildren(id, aType);
+		List<? extends Item> children = storageHubClientService.getFilteredChildren(id, aType, withAccounting, withMapProperties);
 		List<WorkspaceItem> toChildren = new ArrayList<WorkspaceItem>(children.size());
 
 		for (Item item : children) {
-			WorkspaceItem child = HLMapper.toWorkspaceItem(item);
+			WorkspaceItem child = HLMapper.toWorkspaceItem(item, withAccounting, withFileDetails, withMapProperties);
 			toChildren.add(child);
 		}
 
@@ -305,7 +316,7 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 		List<WorkspaceItem> toParents = new ArrayList<WorkspaceItem>(parents.size());
 
 		for (Item item : parents) {
-			WorkspaceItem child = HLMapper.toWorkspaceItem(item);
+			WorkspaceItem child = HLMapper.toWorkspaceItem(item, withAccounting, withFileDetails, withMapProperties);
 			toParents.add(child);
 		}
 
@@ -327,7 +338,7 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 		Item item;
 		try {
 			item = storageHubClientService.createFolder(destinationFolderId, name, description);
-			return (WorkspaceFolder) HLMapper.toWorkspaceItem(item);
+			return (WorkspaceFolder) HLMapper.toWorkspaceItem(item, withAccounting, withFileDetails, withMapProperties);
 		}
 		catch (Exception e) {
 			logger.error("Error on creating the folder: ",e);
@@ -358,7 +369,7 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 		Validate.notNull(itemId,"The input itemId is null");
 		Item item;
 		try {
-			item = storageHubClientService.getItem(itemId);
+			item = storageHubClientService.getItem(itemId, withAccounting, withMapProperties);
 		}
 		catch (Exception e) {
 			logger.error("Error during get item with id: "+itemId,e);
@@ -874,7 +885,7 @@ public final class WorkspaceStorageHubClientService implements Workspace{
     		if(thumbBytes==null || thumbBytes.length==0)
     			throw new Exception("Thumbnail Data is not available for image with id: "+itemId);
 
-			return new org.gcube.common.storagehubwrapper.shared.tohl.impl.StreamDescriptor(new ByteArrayInputStream(thumbBytes), null, new Long(thumbBytes.length),imgContent.getThumbnailMimeType());
+			return new org.gcube.common.storagehubwrapper.shared.tohl.impl.StreamDescriptor(new ByteArrayInputStream(thumbBytes), null, new Long(thumbBytes.length),imgContent.getMimeType());
 
 		}catch(Exception e){
 			logger.error("Error on getThumbnailData for: "+itemId, e);
@@ -1203,5 +1214,4 @@ public final class WorkspaceStorageHubClientService implements Workspace{
 
 
 
-
 }
